@@ -8,7 +8,7 @@
 # to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2022  Kaltura Inc.
+# Copyright (C) 2006-2023  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -99,7 +99,9 @@ class KalturaIntegrationSetting(KalturaObjectBase):
             deletionPolicy=NotImplemented,
             createdAt=NotImplemented,
             updatedAt=NotImplemented,
-            partnerId=NotImplemented):
+            partnerId=NotImplemented,
+            enableMeetingUpload=NotImplemented,
+            enableMeetingChat=NotImplemented):
         KalturaObjectBase.__init__(self)
 
         # @var int
@@ -141,6 +143,12 @@ class KalturaIntegrationSetting(KalturaObjectBase):
         # @readonly
         self.partnerId = partnerId
 
+        # @var KalturaNullableBoolean
+        self.enableMeetingUpload = enableMeetingUpload
+
+        # @var KalturaNullableBoolean
+        self.enableMeetingChat = enableMeetingChat
+
 
     PROPERTY_LOADERS = {
         'id': getXmlNodeInt, 
@@ -154,6 +162,8 @@ class KalturaIntegrationSetting(KalturaObjectBase):
         'createdAt': getXmlNodeText, 
         'updatedAt': getXmlNodeText, 
         'partnerId': getXmlNodeInt, 
+        'enableMeetingUpload': (KalturaEnumsFactory.createInt, "KalturaNullableBoolean"), 
+        'enableMeetingChat': (KalturaEnumsFactory.createInt, "KalturaNullableBoolean"), 
     }
 
     def fromXml(self, node):
@@ -168,6 +178,8 @@ class KalturaIntegrationSetting(KalturaObjectBase):
         kparams.addIntIfDefined("conversionProfileId", self.conversionProfileId)
         kparams.addIntEnumIfDefined("handleParticipantsMode", self.handleParticipantsMode)
         kparams.addIntEnumIfDefined("deletionPolicy", self.deletionPolicy)
+        kparams.addIntEnumIfDefined("enableMeetingUpload", self.enableMeetingUpload)
+        kparams.addIntEnumIfDefined("enableMeetingChat", self.enableMeetingChat)
         return kparams
 
     def getId(self):
@@ -218,6 +230,18 @@ class KalturaIntegrationSetting(KalturaObjectBase):
     def getPartnerId(self):
         return self.partnerId
 
+    def getEnableMeetingUpload(self):
+        return self.enableMeetingUpload
+
+    def setEnableMeetingUpload(self, newEnableMeetingUpload):
+        self.enableMeetingUpload = newEnableMeetingUpload
+
+    def getEnableMeetingChat(self):
+        return self.enableMeetingChat
+
+    def setEnableMeetingChat(self, newEnableMeetingChat):
+        self.enableMeetingChat = newEnableMeetingChat
+
 
 # @package Kaltura
 # @subpackage Client
@@ -234,6 +258,8 @@ class KalturaZoomIntegrationSetting(KalturaIntegrationSetting):
             createdAt=NotImplemented,
             updatedAt=NotImplemented,
             partnerId=NotImplemented,
+            enableMeetingUpload=NotImplemented,
+            enableMeetingChat=NotImplemented,
             zoomCategory=NotImplemented,
             enableRecordingUpload=NotImplemented,
             zoomUserMatchingMode=NotImplemented,
@@ -243,7 +269,6 @@ class KalturaZoomIntegrationSetting(KalturaIntegrationSetting):
             jwtToken=NotImplemented,
             enableZoomTranscription=NotImplemented,
             zoomAccountDescription=NotImplemented,
-            enableMeetingUpload=NotImplemented,
             optOutGroupNames=NotImplemented,
             optInGroupNames=NotImplemented,
             groupParticipationType=NotImplemented):
@@ -258,7 +283,9 @@ class KalturaZoomIntegrationSetting(KalturaIntegrationSetting):
             deletionPolicy,
             createdAt,
             updatedAt,
-            partnerId)
+            partnerId,
+            enableMeetingUpload,
+            enableMeetingChat)
 
         # @var string
         self.zoomCategory = zoomCategory
@@ -287,9 +314,6 @@ class KalturaZoomIntegrationSetting(KalturaIntegrationSetting):
         # @var string
         self.zoomAccountDescription = zoomAccountDescription
 
-        # @var KalturaNullableBoolean
-        self.enableMeetingUpload = enableMeetingUpload
-
         # @var string
         self.optOutGroupNames = optOutGroupNames
 
@@ -310,7 +334,6 @@ class KalturaZoomIntegrationSetting(KalturaIntegrationSetting):
         'jwtToken': getXmlNodeText, 
         'enableZoomTranscription': (KalturaEnumsFactory.createInt, "KalturaNullableBoolean"), 
         'zoomAccountDescription': getXmlNodeText, 
-        'enableMeetingUpload': (KalturaEnumsFactory.createInt, "KalturaNullableBoolean"), 
         'optOutGroupNames': getXmlNodeText, 
         'optInGroupNames': getXmlNodeText, 
         'groupParticipationType': (KalturaEnumsFactory.createInt, "KalturaZoomGroupParticipationType"), 
@@ -332,7 +355,6 @@ class KalturaZoomIntegrationSetting(KalturaIntegrationSetting):
         kparams.addStringIfDefined("jwtToken", self.jwtToken)
         kparams.addIntEnumIfDefined("enableZoomTranscription", self.enableZoomTranscription)
         kparams.addStringIfDefined("zoomAccountDescription", self.zoomAccountDescription)
-        kparams.addIntEnumIfDefined("enableMeetingUpload", self.enableMeetingUpload)
         kparams.addStringIfDefined("optOutGroupNames", self.optOutGroupNames)
         kparams.addStringIfDefined("optInGroupNames", self.optInGroupNames)
         kparams.addIntEnumIfDefined("groupParticipationType", self.groupParticipationType)
@@ -392,12 +414,6 @@ class KalturaZoomIntegrationSetting(KalturaIntegrationSetting):
     def setZoomAccountDescription(self, newZoomAccountDescription):
         self.zoomAccountDescription = newZoomAccountDescription
 
-    def getEnableMeetingUpload(self):
-        return self.enableMeetingUpload
-
-    def setEnableMeetingUpload(self, newEnableMeetingUpload):
-        self.enableMeetingUpload = newEnableMeetingUpload
-
     def getOptOutGroupNames(self):
         return self.optOutGroupNames
 
